'use strict';

var cid = require('multiformats/cid');
var parseDuration = require('parse-duration');
var multiaddr = require('multiaddr');
var toCidAndPath = require('ipfs-core-utils/to-cid-and-path');
var Joi$1 = require('joi');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var parseDuration__default = /*#__PURE__*/_interopDefaultLegacy(parseDuration);
var Joi__default = /*#__PURE__*/_interopDefaultLegacy(Joi$1);

const toIpfsPath = value => {
  if (!value) {
    throw new Error('Must have value');
  }
  value = value.toString();
  let startedWithIpfs = false;
  if (value.startsWith('/ipfs/')) {
    startedWithIpfs = true;
    value = value.replace(/^\/ipfs\//, '');
  }
  const parts = value.split('/');
  parts[0] = cid.CID.parse(parts[0]);
  return `${ startedWithIpfs ? '/ipfs/' : '' }${ parts.join('/') }`;
};
const toCID = value => {
  return cid.CID.parse(value.toString().replace('/ipfs/', ''));
};
const requireIfRequired = (value, helpers) => {
  if (helpers.schema.$_getFlag('presence') === 'required' && !value) {
    return {
      value,
      errors: helpers.error('required')
    };
  }
};
var Joi = Joi__default["default"].extend(joi => {
  return {
    type: 'cid',
    base: joi.any(),
    validate: requireIfRequired,
    coerce(value, _helpers) {
      if (!value) {
        return;
      }
      return { value: toCID(value) };
    }
  };
}, joi => {
  return {
    type: 'ipfsPath',
    base: joi.string(),
    validate: requireIfRequired,
    coerce(value, _helpers) {
      if (!value) {
        return;
      }
      return { value: toIpfsPath(value) };
    }
  };
}, joi => {
  return {
    type: 'multiaddr',
    base: joi.string(),
    validate: requireIfRequired,
    coerce(value, _helpers) {
      if (!value) {
        return;
      }
      return { value: new multiaddr.Multiaddr(value).toString() };
    }
  };
}, joi => {
  return {
    type: 'timeout',
    base: joi.number(),
    validate: requireIfRequired,
    coerce(value, _helpers) {
      if (!value) {
        return;
      }
      return { value: parseDuration__default["default"](value) };
    }
  };
}, joi => {
  return {
    type: 'cidAndPath',
    base: joi.any(),
    validate: requireIfRequired,
    coerce(value, _helpers) {
      if (!value) {
        return;
      }
      return { value: toCidAndPath.toCidAndPath(value) };
    }
  };
}, joi => {
  return {
    type: 'json',
    base: joi.any(),
    validate: requireIfRequired,
    coerce(value, _helpers) {
      if (!value) {
        return;
      }
      return { value: JSON.parse(value) };
    }
  };
});

module.exports = Joi;
